# STA-663-Final-Project

Students: Raghav Agrawal, Peyton Chen

In our term final project for STA 663 - Statistical Computation, we studied the paper titled "Infinite Latent Feature Models
and the Indian Buffet Process" by Thomas L. Griffiths and Zoubin Ghahramani and implememented the algorithms described in the paper.

The `Package` directory contains all the files in our package, which includes the source code. 

The test codes are located in the `Test code` folder. 

The final report of our project can be found in the `Report` direcotry. 

Examples of the implememntation of our algorithms can be found in the `Example` directory. 
